<!DOCTYPE html>
<html>
    <head>
        <meta charset="utf-8">
		<title>Tryout</title>
		<link href="{{STATIC_URL}}css/jtable/jquery-ui.css" rel="stylesheet" type="text/css" />
		<link href="{{STATIC_URL}}css/jtable/jtable.min.css" rel="stylesheet" type="text/css" />
		<script src="{{STATIC_URL}}js/jtable/jquery-1.9.1.js" type="text/javascript"></script>
		<script src="{{STATIC_URL}}js/jtable/jquery-ui.js" type="text/javascript"></script>
		<script src="{{STATIC_URL}}js/jtable/jquery.jtable.min.js" type="text/javascript"></script>
		<link href="{{STATIC_URL}}lightcolor/blue/jtable.css" rel="stylesheet" type="text/css" />
		<script language="javascript">var STATIC_URL = "{{ STATIC_URL|escapejs }}";</script>
		<script src="{{STATIC_URL}}group.js" type="text/javascript"></script>

	</head>

	<body>


    <article>

	<div id="GroupUserMngt" class="grid_16">{% csrf_token %}</div>

	</article>

	</body>
</html>